@@ -161,6 +161,9 @@ private:
     void importComboBoxChange(QString strText);
     void getAllDeviceName();
 
+    //恢复标题显示
+    void restoreTitleDisplay();
+
 signals:
     void sigSearchEditIsDisplay(bool bIsDisp);
     void sigLoadMountImagesStart(QString mountName, QString path);
@@ -203,6 +206,8 @@ private slots:
     void onTrashInfosChanged();
     //删除描述语自适应变化
     void adaptiveTrashDescritionLabel();
+    //批量操作时判断标题栏是否有遮挡情况
+    void onBatchSelectChanged(bool isBatchSelect);
     //默认导入路径已被销毁
     void onMonitorDestroyed(int UID);
 public:
