@@ -61,7 +61,7 @@ LeftListView::LeftListView(QWidget *parent)
 {
     //右侧菜单栏支持滑动
 //    QScroller::grabGesture(viewport());
-    QScrollBar *m_bar = new QScrollBar();
+    m_bar = new QScrollBar();
 //    QScroller::grabGesture(viewport());
     this->setVerticalScrollBar(m_bar);
     m_ItemCurrentDataType = 0;
@@ -206,6 +206,7 @@ void LeftListView::initUI()
     m_pCustomizeListView->setSpacing(0);
     m_pCustomizeListView->setFrameShape(DListWidget::NoFrame);
     m_pCustomizeListView->setContextMenuPolicy(Qt::CustomContextMenu);
+    m_pCustomizeListView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     //自动导入路径
     auto autoImportAlbumNames = DBManager::instance()->getAllAlbumNames(AutoImport);
@@ -380,7 +381,20 @@ void LeftListView::showMenu(const QPoint &pos)
         m_MenuActionMap.value(tr("Export"))->setVisible(false);
     }
 
-    m_pMenu->popup(QCursor::pos());
+    bool needShowMenu = false;
+    for (const auto &eachAction : m_MenuActionMap) {
+        if (eachAction->isVisible()) {
+            needShowMenu = true;
+            break;
+        }
+    }
+
+    //菜单里面可能没有内容，强行显示出来会造成BUG
+    if (needShowMenu) {
+        m_pMenu->popup(QCursor::pos());
+    } else {
+        m_pMenu->setVisible(false);
+    }
 }
 
 void LeftListView::onMenuClicked(QAction *action)
@@ -388,7 +402,7 @@ void LeftListView::onMenuClicked(QAction *action)
     const int id = action->property("MenuID").toInt();
     switch (MenuItemId(id)) {
     case IdStartSlideShow: {
-        auto imagelist = DBManager::instance()->getInfosByAlbum(m_currentUID);
+        auto imagelist = DBManager::instance()->getInfosByAlbum(m_currentUID, false);
         QStringList paths;
         for (auto image : imagelist) {
             paths << image.filePath;
@@ -438,8 +452,6 @@ void LeftListView::onMenuClicked(QAction *action)
             if (dbType == AutoImport) { //自动导入删除步骤
                 DBManager::instance()->removeCustomAutoImportPath(pTabItem->m_UID);
             } else { //常规相册删除步骤
-                QStringList paths = DBManager::instance()->getPathsByAlbum(pTabItem->m_UID);
-                ImageEngineApi::instance()->moveImagesToTrash(paths);
                 DBManager::instance()->removeAlbum(pTabItem->m_UID);
             }
 
