@@ -45,6 +45,11 @@ public:
     void addMovieDurationStr(const QString &path, const QString &durationStr);
     QString getMovieDurationStrByPath(const QString &path);
 
+    void stopFlushThumbnail();
+    void waitFlushThumbnailFinish();
+
+    bool readerIsRunning();
+
 private slots:
 signals:
     void sigeUpdateListview();
@@ -52,6 +57,7 @@ signals:
 public:
 private:
     bool pathInMap(const QString &path);
+    void onNeedReflushThumbnail(const QStringList &paths);
 
     //QImage:图片，bool:是否是从缓存加载
     std::pair<QImage, bool> getImageFromMap(const QString &path);
@@ -83,6 +89,11 @@ public:
         return runningFlag;
     }
 
+    void stopRead()
+    {
+        stopFlag = true;
+    }
+
 public slots:
     void readThumbnail();
 
@@ -90,6 +101,7 @@ private:
     std::deque<QString> needLoadPath;
     QMutex mutex;
     std::atomic_bool runningFlag;
+    std::atomic_bool stopFlag;
 };
 
 #endif // IMAGEDATASERVICE_H
