@@ -42,6 +42,7 @@
 #include "imagedataservice.h"
 #include "movieservice.h"
 #include <QElapsedTimer>
+#include <QtConcurrent/QtConcurrent>
 
 DBImgInfo getDBInfo(const QString &srcpath, bool isVideo)
 {
@@ -215,7 +216,7 @@ void ImportImagesThread::runDetail()
         }
         // 判断当前导入路径是否为外接设备
         bool isMountFlag = false;
-        QList<QExplicitlySharedDataPointer<DGioMount>> mounts = DGioVolumeManager::getMounts();
+        auto mounts = utils::base::getMounts_safe();
         for (auto mount : mounts) {
             if (bneedstop || ImageEngineApi::instance()->closeFg()) {
                 m_obj->imageImported(false);
@@ -290,32 +291,53 @@ void ImportImagesThread::runDetail()
             if (m_dbType != AutoImport || m_isFirst) {
                 emit dApp->signalM->progressOfWaitDialog(image_list.size(), dbInfos.size());
             }
-
         }
 
         std::sort(dbInfos.begin(), dbInfos.end(), [](const DBImgInfo & lhs, const DBImgInfo & rhs) {
-            return lhs.changeTime.toTime_t() > rhs.changeTime.toTime_t();
+            return lhs.changeTime > rhs.changeTime;
         });
 
-        QStringList pathlistImport;
-        for (auto &dbInfo : dbInfos) {
-            if (!DBManager::instance()->isImgExistInAlbum(m_UID, dbInfo.filePath, m_dbType))
-                pathlistImport << dbInfo.filePath;
+        //性能测试是测导入提示框消失到第一屏缩略图加载完毕的时间
+        //因此在提示框进行的时候预先加载第一屏的图片
+        QFuture<void> firstImportWatcher;
+        bool doLoadFirstPage = (DBManager::instance()->getImgsCount() == 0 && m_dbType != AutoImport && !SignalManager::inAutoImport);
+        QStringList firstLoadPaths; //这个变量要写外面，写里面会造成提前销毁，然后在多线程加载中崩溃
+        if (doLoadFirstPage) {
+            for (int i = 0; i < 70 && i < dbInfos.size(); ++i) {
+                firstLoadPaths.push_back(dbInfos[i].filePath);
+            }
+            firstImportWatcher = utils::base::multiLoadImage(firstLoadPaths);
         }
-        //导入相册数据库AlbumTable3
-        if (pathlistImport.size() > 0) {
-            DBManager::instance()->insertIntoAlbum(m_UID, pathlistImport, m_dbType);
-        }
-        //已全部存在，无需导入
-        if (noReadCount == image_list.size()) {
-            m_obj->imageImported(false);
-            m_obj->removeThread(this);
-            return;
+
+        if (m_UID >= 0) {
+            //导入相册数据库AlbumTable3
+            QStringList pathlistImport;
+            for (auto &dbInfo : dbInfos) {
+                if (!DBManager::instance()->isImgExistInAlbum(m_UID, dbInfo.filePath))
+                    pathlistImport << dbInfo.filePath;
+            }
+
+            if (!pathlistImport.isEmpty()) {
+                DBManager::instance()->insertIntoAlbum(m_UID, pathlistImport, m_dbType);
+            }
+
+            //已全部存在，无需导入
+            if (noReadCount == image_list.size()) {
+                m_obj->imageImported(false);
+                m_obj->removeThread(this);
+                return;
+            }
         }
+
         //bug112005只有在确认有需要导入的文件时才显示导入进度
         if (m_dbType != AutoImport || m_isFirst) {
             emit dApp->signalM->popupWaitDialog(QObject::tr("Importing..."));
         }
+
+        if (doLoadFirstPage) {
+            firstImportWatcher.waitForFinished();
+        }
+
         //导入图片数据库ImageTable3
         DBManager::instance()->insertImgInfos(dbInfos);
         if (m_dbType != AutoImport || m_isFirst) {
@@ -336,7 +358,7 @@ void ImportImagesThread::runDetail()
             pathlist << Info.filePath;
         }
 
-        if (!(m_dbType == AutoImport && !m_isFirst)) {
+        if (m_dbType != AutoImport || m_isFirst) {
             if (image_list.length() == pathlist.length() && !pathlist.isEmpty()) {
                 emit dApp->signalM->updateStatusBarImportLabel(pathlist, 1, m_albumname);
                 emit dApp->signalM->ImportSuccess(); //导入成功
@@ -435,9 +457,9 @@ void ImageMoveImagesToTrashThread::runDetail()
             DBImgInfo info;
             info = DBManager::instance()->getInfoByPath(path);
             info.importTime = QDateTime::currentDateTime();
-            auto allalbumnames = DBManager::instance()->getAllAlbumNames();
             //first是UID，secend是album name
             //获取生前所属相册UID，有需要再放开
+            //auto allalbumnames = DBManager::instance()->getAllAlbumNames();
             /*for (auto eachname : allalbumnames) {
                 if (DBManager::instance()->isImgExistInAlbum(eachname.first, path)) {
                     info.albumUID += (QString::number(eachname.first) + ",");
@@ -602,7 +624,9 @@ void ImageLoadFromDBThread::runDetail()
     }
 
     //删除数据库失效的图片
-    DBManager::instance()->removeImgInfosNoSignal(fail_image_list);
+    QtConcurrent::run([fail_image_list]() {
+        DBManager::instance()->removeImgInfosNoSignal(fail_image_list);
+    });
 
     emit ImageEngineApi::instance()->sigReloadAfterFilterEnd(allImageDataVector);
 }
