@@ -193,9 +193,18 @@ void ImportTimeLineView::slotBatchSelectChanged(bool isBatchSelect)
     if (isBatchSelect) {
         m_choseBtnItem->setVisible(true);
         m_importTimeLineListView->resetBlankItemHeight(ChoseBtn_HEIGHT + title_HEIGHT);
+        //维语特殊处理
+        if (QLocale::system().language() == QLocale::Uighur) {
+            m_DateNumLabel->hide();
+            m_pImportTitle->hide();
+        }
     } else {
         m_choseBtnItem->setVisible(false);
         m_importTimeLineListView->resetBlankItemHeight(title_HEIGHT);
+        if (QLocale::system().language() == QLocale::Uighur) {
+            m_DateNumLabel->show();
+            m_pImportTitle->show();
+        }
     }
 }
 
@@ -307,12 +316,27 @@ void ImportTimeLineView::initTimeLineViewWidget()
     m_batchOperateWidget = new BatchOperateWidget(m_importTimeLineListView, BatchOperateWidget::NullType, this);
     //进入批量状态
     connect(m_batchOperateWidget, &BatchOperateWidget::signalBatchSelectChanged, this, &ImportTimeLineView::slotBatchSelectChanged);
+    connect(m_batchOperateWidget, &BatchOperateWidget::sigCancelAll, this, [ = ](bool cancel) {
+        Q_UNUSED(cancel)
+        if (QLocale::system().language() == QLocale::Uigur)
+            return;
+        int size = m_batchOperateWidget->x() - (m_pImportTitle->x() + m_pImportTitle->width());
+        QString Str = utils::base::reorganizationStr(m_pImportTitle->font(), tr("Import"), m_pImportTitle->width() + size);
+        if (Str.length() > 0) {
+            m_pImportTitle->show();
+            m_pImportTitle->raise();
+        } else {
+            m_pImportTitle->hide();
+        }
+        m_pImportTitle->setText(Str);
+    }, Qt::QueuedConnection);
     TitleLayout->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     TitleLayout->addWidget(m_batchOperateWidget);
 
     //已导入
     m_pImportTitle = new DLabel(m_timeLineViewWidget);
     m_pImportTitle->setText(tr("Import"));
+    m_pImportTitle->setToolTip(tr("Import"));
     m_pImportTitle->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
     DFontSizeManager::instance()->bind(m_pImportTitle, DFontSizeManager::T3, QFont::DemiBold);
     m_pImportTitle->setForegroundRole(DPalette::TextTitle);
@@ -324,7 +348,7 @@ void ImportTimeLineView::initTimeLineViewWidget()
     m_pImportTitle->setPalette(ppal_light2);
     m_pImportTitle->setGraphicsEffect(opacityEffect_light2);
     m_pImportTitle->setAutoFillBackground(true);
-    m_pImportTitle->setFixedWidth(150);//BUG#93470，手动调大控件长度（英语模式下最后那个t会部分遮挡）
+    m_pImportTitle->adjustSize();
 
     m_choseBtnItem = new DWidget(m_timeLineViewWidget);
     QHBoxLayout *btnLayout = new QHBoxLayout();
@@ -365,12 +389,11 @@ void ImportTimeLineView::clearAndStartLayout()
     //后面的listview就有了正确的宽度，该信号槽就不需要再连接
     disconnect(m_importTimeLineListView, &ThumbnailListView::sigShowEvent, this, &ImportTimeLineView::clearAndStartLayout);
     qDebug() << "------" << __FUNCTION__ << "";
-    m_timelines.clear();
+
     //获取所有时间线
     m_timelines = DBManager::instance()->getImportTimelines();
     qDebug() << __func__ << m_timelines.size();
 
-
     if (0 < m_timelines.size()) {
     } else {
         m_choseBtnItem->setVisible(false);
@@ -389,7 +412,7 @@ void ImportTimeLineView::addTimelineLayout()
 
         //加时间线标题
         QString date, num;
-        QStringList dateTimeList = m_timelines.at(timelineIndex).split(" ");
+        QStringList dateTimeList = m_timelines.at(timelineIndex).toString("yyyy.MM.dd hh:mm").split(" ");
         QStringList datelist = dateTimeList.at(0).split(".");
         if (datelist.count() > 2) {
             if (dateTimeList.count() == 2) {
@@ -588,4 +611,16 @@ void ImportTimeLineView::updateDateNumLabel()
     } else {
         m_DateNumLabel->setToolTip("");
     }
+    if (QLocale::system().language() == QLocale::Uighur)
+        return;
+    //判断批量操作栏和标题栏相对位置，对标题栏进行设置
+    int size = m_batchOperateWidget->x() - (m_pImportTitle->x() + m_pImportTitle->width());
+    QString Str = utils::base::reorganizationStr(m_pImportTitle->font(), tr("Import"), m_pImportTitle->width() + size);
+    if (Str.length() > 0) {
+        m_pImportTitle->show();
+        m_pImportTitle->raise();
+    } else {
+        m_pImportTitle->hide();
+    }
+    m_pImportTitle->setText(Str);
 }
