@@ -50,6 +50,7 @@
 #include <DWidgetUtil>
 #include <DStandardPaths>
 #include <set>
+#include <QtConcurrent/QtConcurrent>
 
 #include "imagedataservice.h"
 #include "movieservice.h"
@@ -71,28 +72,6 @@ const int VIEW_SLIDE = 5;
 using namespace utils::common;
 MainWindow::MainWindow()
     : m_iCurrentView(VIEW_ALLPIC)
-    , m_bImport(false)
-    , m_titleBtnWidget(nullptr)
-    , m_pTitleBarMenu(nullptr)
-    , m_pCenterWidget(nullptr)
-    , m_pAlbumview(nullptr)
-    , m_pAlbumWidget(nullptr)
-    , m_pAllPicView(nullptr)
-    , m_pTimeLineView(nullptr)
-    , m_pTimeLineWidget(nullptr)
-    , m_pSearchView(nullptr)
-    , m_pSearchEdit(nullptr)
-    , m_backIndex(0)
-    , m_pSliderPos(2)
-    , btnGroup(nullptr)
-    , m_pAllPicBtn(nullptr)
-    , m_pTimeBtn(nullptr)
-    , m_pAlbumBtn(nullptr)
-    , m_waitdailog(nullptr)
-    , m_importBar(nullptr)
-    , m_waitlabel(nullptr)
-    , m_countLabel(nullptr)
-    , m_settings(nullptr)
     , m_fileInotifygroup(new FileInotifyGroup(this))
 {
     this->setObjectName("drawMainWindow");
@@ -205,8 +184,8 @@ void MainWindow::initConnections()
     connect(dApp->signalM, &SignalManager::startSlideShow, [this](const SignalManager::ViewInfo & vinfo) {
         this->onSigViewImage(vinfo, Operation_StartSliderShow, false, "", -1);
     });
-    //隐藏幻灯片显示
-    connect(ImageEngine::instance(), &ImageEngine::exitSlideShow, this, &MainWindow::onHideSlidePanel);
+    //image-editor隐藏退出全屏显示
+    connect(ImageEngine::instance(), &ImageEngine::exitSlideShow, this, &MainWindow::onHideFromFullScreen);
     //导出图片
     connect(dApp->signalM, &SignalManager::exportImage, this, &MainWindow::onExportImage);
 //    connect(dApp->signalM, &SignalManager::showImageInfo, this, &MainWindow::onShowImageInfo);
@@ -1404,7 +1383,7 @@ void MainWindow::updateCollectButton()
     if (path.isEmpty()) {
         return;
     }
-    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path, AlbumDBType::Favourite)) {
+    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path)) {
         m_collect->setToolTip(tr("Unfavorite"));
         m_collect->setIcon(QIcon::fromTheme("dcc_ccollection"));
         m_collect->setIconSize(QSize(36, 36));
@@ -1429,7 +1408,6 @@ void MainWindow::onLibDel(QString path)
         return;
     }
 
-
     DBImgInfo info;
     info = DBManager::instance()->getInfoByPath(path);
     info.importTime = QDateTime::currentDateTime();
@@ -1447,11 +1425,6 @@ void MainWindow::onLibDel(QString path)
     } else {
         deleteSaveImage();
     }
-
-
-
-
-
 }
 
 void MainWindow::deleteSaveImage()
@@ -1488,7 +1461,7 @@ void MainWindow::onAddToAlbum(bool isNew, int UID, const QString &path)
 void MainWindow::onAddOrRemoveToFav(const QString &path, bool isAdd)
 {
     Q_UNUSED(isAdd)
-    if (!DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path, AlbumDBType::Favourite)) {//收藏
+    if (!DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path)) {//收藏
         DBManager::instance()->insertIntoAlbum(DBManager::SpUID::u_Favorite, QStringList(path), AlbumDBType::Favourite);
         emit dApp->signalM->insertedIntoAlbum(DBManager::SpUID::u_Favorite, QStringList(path));
     } else { //取消收藏
@@ -1626,11 +1599,6 @@ void MainWindow::onHideImageView()
     setTitleBarHideden(false);
     m_pCenterWidget->setCurrentIndex(m_backIndex);
 
-    //外部打开图片，返回时默认跳转到所有照片界面
-    if (m_backIndex == VIEW_ALLPIC) {
-        allPicBtnClicked();
-    }
-
     setConflictShortcutEnabled(true);
 }
 
@@ -1644,7 +1612,7 @@ void MainWindow::onCollectButtonClicked()
     if (path.isEmpty()) {
         return;
     }
-    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path, AlbumDBType::Favourite)) {
+    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path)) {
         DBManager::instance()->removeFromAlbum(DBManager::SpUID::u_Favorite, QStringList(path), AlbumDBType::Favourite);
         m_collect->setToolTip(tr("Favorite"));
         m_collect->setIcon(QIcon::fromTheme("dcc_collection_normal"));
@@ -1662,6 +1630,51 @@ QButtonGroup *MainWindow::getButG()
     return (nullptr != static_cast<QButtonGroup *>(btnGroup) ? btnGroup : nullptr);
 }
 
+void MainWindow::waitImportantProcessBeforeExit()
+{
+    //0.展示蒙版阻塞效果
+    auto maskLayer = new QWidget(this);
+    maskLayer->setStyleSheet("background-color: rgba(255, 255, 255, 180);"); //设置颜色及不透明度
+    maskLayer->setFixedSize(this->size()); //设置窗口大小
+    maskLayer->setVisible(true); //显示蒙版
+    this->stackUnder(maskLayer); //将蒙版安装到主窗口
+
+    //0.1 转圈效果
+    constexpr int fixSize = 48;
+    auto spinner = new DSpinner(maskLayer);
+    spinner->setFixedSize(QSize(fixSize, fixSize)); //设置窗口大小
+    spinner->setVisible(true); //显示蒙版
+    maskLayer->stackUnder(spinner); //将转圈安装到蒙版
+    spinner->move((maskLayer->width() - fixSize) / 2, (maskLayer->height() - fixSize) / 2);
+    spinner->start();
+
+    //1.停止正在进行的工作，在次线程进行，保证蒙版效果出来
+
+    volatile std::atomic_bool canExit;
+    canExit = false;
+
+    auto watcher = QtConcurrent::run([&canExit]() {
+        //1.1停止
+        ImageEngineApi::instance()->stopRotate();
+        ImageDataService::instance()->stopFlushThumbnail();
+
+        //1.2等待
+        ImageEngineApi::instance()->waitRotateStop();
+        ImageDataService::instance()->waitFlushThumbnailFinish();
+
+        //1.3强制文件写入
+        std::system("sync");
+
+        canExit = true;
+    });
+
+    //采用轮询机制保证转圈生效
+    while (!canExit) {
+        QThread::msleep(10); //降低轮询产生的CPU消耗
+        QApplication::processEvents();
+    }
+}
+
 void MainWindow::closeEvent(QCloseEvent *event)
 {
     saveWindowState();
@@ -1670,6 +1683,10 @@ void MainWindow::closeEvent(QCloseEvent *event)
         emit dApp->signalM->sigPauseOrStart(false);     //唤醒外设后台挂载
         event->ignore();
     } else {
+        //等待重要操作
+        waitImportantProcessBeforeExit();
+
+        //执行退出
         event->accept();
     }
 }
@@ -1718,7 +1735,9 @@ void MainWindow::showEvent(QShowEvent *event)
     static bool isFirst = true;
     if (isFirst) {
         isFirst = false;
-        ImportImagesFromCustomAutoPaths();
+        QtConcurrent::run([this]() {
+            ImportImagesFromCustomAutoPaths();
+        });
     }
 }
 
@@ -2069,12 +2088,6 @@ void MainWindow::setTitleBarHideden(bool hide)
     }
 }
 
-void MainWindow::closeFromMenu()
-{
-    //这个函数是从overrideVfptrFun进来的，要指定obj对象
-    instance().close();
-}
-
 void MainWindow::onButtonClicked(int id)
 {
     if (0 == id) {
@@ -2197,6 +2210,8 @@ void MainWindow::onImagesRemoved()
 
 void MainWindow::ImportImagesFromCustomAutoPaths()
 {
+    SignalManager::inAutoImport = true;
+
     auto customAutoImportUIDAndPaths = DBManager::instance()->getAllCustomAutoImportUIDAndPath();
 
     //first -> UID, secend -> path
@@ -2219,18 +2234,17 @@ void MainWindow::ImportImagesFromCustomAutoPaths()
         });
 
         //3.1获取已不存在的路径
-        QStringList deleteFiles;
-        for (int i = 0; i != originPaths.size(); ++i) {
-            if (!currentPaths.contains(originPaths[i])) {
-                deleteFiles << originPaths[i];
-            }
-        }
+        QFuture<QString> watcher = QtConcurrent::filtered(originPaths, [currentPaths](const QString & path) {
+            return !currentPaths.contains(path);
+        });
+        watcher.waitForFinished();
+        QStringList deleteFiles(watcher.results());
 
         //3.2移除已导入的路径
-        auto removeIter = std::remove_if(currentPaths.begin(), currentPaths.end(), [originPaths](const QString & path) {
-            return originPaths.contains(path);
+        auto watcher2 = QtConcurrent::filter(currentPaths, [originPaths](const QString & path) {
+            return !originPaths.contains(path);
         });
-        currentPaths.erase(removeIter, currentPaths.end());
+        watcher2.waitForFinished();
 
         //注意：导入新图由于需要制作缩略图，因此是异步多线程的，而移除不存在的图只需要操作数据库，所以是单线程的
         //所以先执行移除，再执行导入
@@ -2245,6 +2259,8 @@ void MainWindow::ImportImagesFromCustomAutoPaths()
             ImageEngineApi::instance()->ImportImagesFromFileList(currentPaths, eachItem.second.split('/').last(), eachItem.first, this, true, AutoImport);
         }
     }
+
+    SignalManager::inAutoImport = false;
 }
 
 void MainWindow::setConflictShortcutEnabled(bool enable)
@@ -2270,7 +2286,7 @@ void MainWindow::onAddImageBtnClicked(bool checked)
     emit sigTitleMenuImportClicked();
 }
 
-void MainWindow::onHideSlidePanel()
+void MainWindow::onHideFromFullScreen()
 {
     if (VIEW_IMAGE != m_backIndex_fromFullScreen) {
         setTitleBarHideden(false);
@@ -2493,7 +2509,7 @@ void MainWindow::onSendAlbumName(const QString &path)
         }
     }
     bool isFav = false;
-    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path, AlbumDBType::Favourite)) {
+    if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, path)) {
         isFav = true;
     }
 
