@@ -137,7 +137,7 @@ void SearchView::initSearchResultView()
     QVBoxLayout *pSearchResultbodyLayout = new QVBoxLayout();
     pSearchResultbodyLayout->setContentsMargins(8, 0, 0, 0);//搜索界面各边距
     //LMH0417 bug号20706
-    m_pThumbnailListView = new ThumbnailListView(ThumbnailDelegate::SearchViewType, COMMON_STR_SEARCH);
+    m_pThumbnailListView = new ThumbnailListView(ThumbnailDelegate::SearchViewType, -1, COMMON_STR_SEARCH);
 
     m_pThumbnailListView->setFrameShape(QListView::NoFrame);
 
@@ -178,9 +178,10 @@ void SearchView::initMainStackWidget()
     layout->addWidget(m_stackWidget);
 }
 
-void SearchView::improtSearchResultsIntoThumbnailView(QString s, const QString &album)
+void SearchView::improtSearchResultsIntoThumbnailView(QString s, const QString &album, int UID)
 {
     m_albumName = album;
+    m_UID = UID;
     using namespace utils::image;
     m_keywords = s;
     QList<DBImgInfo> thumbnaiItemList;
@@ -192,7 +193,7 @@ void SearchView::improtSearchResultsIntoThumbnailView(QString s, const QString &
     } else if (COMMON_STR_TRASH == m_albumName) {
         infos = DBManager::instance()->getTrashInfosForKeyword(s);
     } else {
-        infos = DBManager::instance()->getInfosForKeyword(m_albumName, s);
+        infos = DBManager::instance()->getInfosForKeyword(m_UID, s);
     }
 
     if (0 < infos.length()) {
@@ -258,7 +259,7 @@ void SearchView::onSlideShowBtnClicked()
     } else if (COMMON_STR_TRASH == m_albumName) {
         imagelist = DBManager::instance()->getTrashInfosForKeyword(m_keywords);
     } else {
-        imagelist = DBManager::instance()->getInfosForKeyword(m_albumName, m_keywords);
+        imagelist = DBManager::instance()->getInfosForKeyword(m_UID, m_keywords);
     }
 
     QStringList paths;
@@ -277,9 +278,9 @@ void SearchView::onOpenImage(int row, const QString &path, bool bFullScreen)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
     info.fullScreen = bFullScreen;
-    auto imagelist = m_pThumbnailListView->getFileList(row);
+    auto imagelist = m_pThumbnailListView->getFileList(row, ItemType::ItemTypePic);
     if (imagelist.size() > 0) {
         info.paths << imagelist;
         info.path = path;
@@ -289,14 +290,18 @@ void SearchView::onOpenImage(int row, const QString &path, bool bFullScreen)
     info.dBImgInfos = m_pThumbnailListView->getAllFileInfo(row);
     info.viewType = utils::common::VIEW_SEARCH_SRN;
 
-    emit dApp->signalM->viewImage(info);
-
     if (COMMON_STR_ALLPHOTOS == m_albumName) {
-        emit dApp->signalM->showImageView(0);
+        info.viewMainWindowID = 0;
     } else if (COMMON_STR_TIMELINE == m_albumName) {
-        emit dApp->signalM->showImageView(1);
+        info.viewMainWindowID = 1;
     } else {
-        emit dApp->signalM->showImageView(2);
+        info.viewMainWindowID = 2;
+    }
+
+    if (bFullScreen) {
+        emit dApp->signalM->sigViewImage(info, Operation_FullScreen);
+    } else {
+        emit dApp->signalM->sigViewImage(info, Operation_NoOperation);
     }
 }
 
@@ -304,7 +309,7 @@ void SearchView::onSlideShow(const QString &path)
 {
     SignalManager::ViewInfo info;
     info.album = "";
-    info.lastPanel = nullptr;
+//    info.lastPanel = nullptr;  //todo imageviewer
     auto photolist = m_pThumbnailListView->selectedPaths();
     if (photolist.size() > 1) {
         //如果选中数目大于1，则幻灯片播放选中项
@@ -319,19 +324,11 @@ void SearchView::onSlideShow(const QString &path)
     info.slideShow = true;
     info.viewType = utils::common::VIEW_SEARCH_SRN;
     emit dApp->signalM->startSlideShow(info);
-
-    if (COMMON_STR_ALLPHOTOS == m_albumName) {
-        emit dApp->signalM->showSlidePanel(0);
-    } else if (COMMON_STR_TIMELINE == m_albumName) {
-        emit dApp->signalM->showSlidePanel(1);
-    } else {
-        emit dApp->signalM->showSlidePanel(2);
-    }
 }
 
 void SearchView::updateSearchResultsIntoThumbnailView()
 {
-    improtSearchResultsIntoThumbnailView(m_keywords, m_albumName);
+    improtSearchResultsIntoThumbnailView(m_keywords, m_albumName, m_UID);
 }
 
 void SearchView::changeTheme()
