@@ -32,6 +32,7 @@
 #include <QPropertyAnimation>
 #include <QDesktopServices>
 #include <QProcess>
+#include <QElapsedTimer>
 
 #include "controller/signalmanager.h"
 #include "controller/wallpapersetter.h"
@@ -202,21 +203,19 @@ void ThumbnailListView::mousePressEvent(QMouseEvent *event)
 
 void ThumbnailListView::mouseMoveEvent(QMouseEvent *event)
 {
+    QRectF rect(QPointF((lastTouchBeginPos.x() - 30), (lastTouchBeginPos.y() - 30)),
+                QPointF((lastTouchBeginPos.x() + 30), (lastTouchBeginPos.y() + 30)));
+    if (rect.contains(event->pos())) {
+        return;
+    }
+
     if (touchStatus == 0) {
-        QRectF rect(QPointF((lastTouchBeginPos.x() - 30), (lastTouchBeginPos.y() - 30)),
-                    QPointF((lastTouchBeginPos.x() + 30), (lastTouchBeginPos.y() + 30)));
-        if (rect.contains(event->pos())) {
-            return;
-        } else {
-            touchStatus = 1;
-            activeClick = false;
-        }
+        touchStatus = 1;
+        activeClick = false;
     }
 
     if (touchStatus == 1) {
         if (event->source() == Qt::MouseEventSynthesizedByQt) {
-            //todo
-//            emit sigNeedMoveScorll(-(event->pos() - lastTouchBeginPos).y());
         }
     }
 
@@ -424,7 +423,7 @@ void ThumbnailListView::insertThumbnail(const DBImgInfo &dBImgInfo)
         QModelIndex index = m_model->indexFromItem(item);
         TimeLineDateWidget *pCurrentDateWidget = new TimeLineDateWidget(item, info.date, info.num);
         connect(pCurrentDateWidget, &TimeLineDateWidget::sigIsSelectCurrentDatePic, this, &ThumbnailListView::slotSelectCurrentDatePic);
-        this->setIndexWidget(index, pCurrentDateWidget); //时间线打开速度慢的原因，目前两个时间线初始化的时候走下面那个insertThumbnails，其余的走这里
+        this->setIndexWidget(index, pCurrentDateWidget);
     } else if (info.itemType == ItemTypeImportTimeLineTitle) {
         QModelIndex index = m_model->indexFromItem(item);
         importTimeLineDateWidget *pCurrentDateWidget = new importTimeLineDateWidget(item, info.date, info.num);
@@ -668,7 +667,8 @@ void ThumbnailListView::updateMenuContents()
             m_MenuActionMap.value(tr("Fullscreen"))->setEnabled(false);
             m_MenuActionMap.value(tr("Slide show"))->setEnabled(false);
             m_MenuActionMap.value(tr("Export"))->setEnabled(false);
-            m_albumMenu->deleteLater();
+            if (m_albumMenu)
+                m_albumMenu->deleteLater();
             m_albumMenu = createAlbumMenu();
             if (m_albumMenu) {
                 QAction *action = m_MenuActionMap.value(tr("Export"));
@@ -688,7 +688,7 @@ void ThumbnailListView::updateMenuContents()
 #ifndef tablet_PC
             m_MenuActionMap.value(tr("Print"))->setVisible(false);
 #endif
-            if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, paths[0], AlbumDBType::Favourite)) {
+            if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, paths[0])) {
                 m_MenuActionMap.value(tr("Favorite"))->setVisible(false);
                 m_MenuActionMap.value(tr("Unfavorite"))->setEnabled(false);
             } else {
@@ -719,12 +719,16 @@ void ThumbnailListView::updateMenuContents()
         m_MenuActionMap.value(tr("Fullscreen"))->setVisible(false);
     }
 #endif
-    QFileInfo info(paths[0]);
 
-    if (COMMON_STR_TRASH == m_imageType || !QFileInfo(info.dir(), info.dir().path()).isWritable()) {
+    if (COMMON_STR_TRASH == m_imageType) {
         m_MenuActionMap.value(tr("Delete"))->setVisible(false);
     } else {
-        m_MenuActionMap.value(tr("Delete"))->setVisible(true);
+        if (!isSelectedCanUseDelete()) {
+            m_MenuActionMap.value(tr("Delete"))->setVisible(false);
+        } else {
+            m_MenuActionMap.value(tr("Delete"))->setVisible(true);
+        }
+
         if (m_albumMenu)
             m_albumMenu->deleteLater();
         m_albumMenu = createAlbumMenu();
@@ -737,9 +741,10 @@ void ThumbnailListView::updateMenuContents()
             m_pMenu->insertMenu(action, m_albumMenu);
         }
     }
+
     //非最近删除的单选
     if (1 == paths.length() && COMMON_STR_TRASH != m_imageType) {
-        if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, paths[0], AlbumDBType::Favourite)) {
+        if (DBManager::instance()->isImgExistInAlbum(DBManager::SpUID::u_Favorite, paths[0])) {
             m_MenuActionMap.value(tr("Favorite"))->setVisible(false);
         } else {
             m_MenuActionMap.value(tr("Unfavorite"))->setVisible(false);
@@ -1056,16 +1061,12 @@ void ThumbnailListView::menuItemDeal(QStringList paths, QAction *action)
     break;
     case IdRotateClockwise: {
         //发送给子线程旋转图片
-        for (int i = 0; i < paths.size(); i++) {
-            emit ImageEngineApi::instance()->sigRotateImageFile(90, paths.at(i));
-        }
+        emit ImageEngineApi::instance()->sigRotateImageFile(90, paths);
     }
     break;
     case IdRotateCounterclockwise: {
         //发送给子线程旋转图片
-        for (int i = 0; i < paths.size(); i++) {
-            emit ImageEngineApi::instance()->sigRotateImageFile(-90, paths.at(i));
-        }
+        emit ImageEngineApi::instance()->sigRotateImageFile(-90, paths);
     }
     break;
     case IdSetAsWallpaper:
@@ -1234,7 +1235,6 @@ bool ThumbnailListView::getCurrentIndexSelectStatus(const QModelIndex &index, bo
     if (!index.isValid()) {
         return false;
     }
-    QModelIndexList list = selectionModel()->selectedIndexes();
     if (isPic) {
         //图片，向前循环判断选中状态
         for (int i = index.row(); i > 0; i--) {
@@ -1244,7 +1244,7 @@ bool ThumbnailListView::getCurrentIndexSelectStatus(const QModelIndex &index, bo
                     || tempdata.itemType == ItemTypeImportTimeLineTitle) {
                 break;
             }
-            if (!list.contains(idx)) {
+            if (!selectionModel()->isSelected(idx)) {
                 return false;
             }
         }
@@ -1256,7 +1256,7 @@ bool ThumbnailListView::getCurrentIndexSelectStatus(const QModelIndex &index, bo
                     || tempdata.itemType == ItemTypeImportTimeLineTitle) {
                 break;
             }
-            if (!list.contains(idx)) {
+            if (!selectionModel()->isSelected(idx)) {
                 return false;
             }
         }
@@ -1268,7 +1268,7 @@ bool ThumbnailListView::getCurrentIndexSelectStatus(const QModelIndex &index, bo
                     || tempdata.itemType == ItemTypeImportTimeLineTitle) {
                 break;
             }
-            if (!list.contains(idx)) {
+            if (!selectionModel()->isSelected(idx)) {
                 return false;
             }
         }
@@ -1387,14 +1387,12 @@ void ThumbnailListView::updateThumbnailViewAfterDelete(const QStringList &paths)
             || m_delegatetype == ThumbnailDelegate::AlbumViewFavoriteType
             || m_delegatetype == ThumbnailDelegate::TimeLineViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewImportTimeLineViewType) {
-        for (const auto &path : paths) {
-            for (int i = (m_model->rowCount() - 1); i >= 0; i--) {
-                QModelIndex index = m_model->index(i, 0);
-                DBImgInfo data = index.data(Qt::DisplayRole).value<DBImgInfo>();
-                if (path == data.filePath) {
-                    m_model->removeRow(i);
-                    break;
-                }
+        for (int i = (m_model->rowCount() - 1); i >= 0; i--) {
+            QModelIndex index = m_model->index(i, 0);
+            DBImgInfo data = index.data(Qt::DisplayRole).value<DBImgInfo>();
+            if (paths.contains(data.filePath)) { //你永远可以相信QStringList::contains
+                m_model->removeRow(i);
+                break;
             }
         }
     }
@@ -1516,22 +1514,29 @@ void ThumbnailListView::selectPhotos(const QStringList &paths)
                    m_batchOperateWidget, &BatchOperateWidget::sltSelectionChanged);
     }
     QModelIndex firstIndex;
+
     if (!paths.isEmpty()) {
         this->clearSelection();
+        QElapsedTimer timer_4s;
+        timer_4s.start();
         for (int i = 0; i < m_model->rowCount(); i++) {
             QModelIndex index = m_model->index(i, 0);
             DBImgInfo info = index.data(Qt::DisplayRole).value<DBImgInfo>();
-            for (int j = 0; j < paths.count(); j++) {
-                if (info.filePath == paths.at(j)) {
-                    // 选中
-                    selectionModel()->select(index, QItemSelectionModel::Select);
-                    if (!firstIndex.isValid()) {
-                        firstIndex = index;
-                    }
+
+            if (paths.contains(info.filePath)) {
+                // 选中
+                selectionModel()->select(index, QItemSelectionModel::Select); //主要耗时点
+                if (!firstIndex.isValid()) {
+                    firstIndex = index;
                 }
             }
+
+            if (timer_4s.elapsed() > 4000) { //只给4秒时间，能选多少选多少
+                break;
+            }
         }
     }
+
     // 定位第一个重复导入的照片
     if (firstIndex.isValid()) {
         this->scrollTo(firstIndex, ScrollHint::PositionAtCenter);
@@ -1619,9 +1624,6 @@ void ThumbnailListView::insertThumbnailByImgInfos(DBImgInfoList infoList)
         DBImgInfo info = infoList.at(i);
         info.imgWidth = m_onePicWidth;
         info.imgHeight = m_onePicWidth;
-        if (m_delegatetype == ThumbnailDelegate::AlbumViewTrashType) {
-            info.remainDays = 30 - utils::base::daysDifferenceBetweenTime(info.importTime, currentTime);
-        }
         insertThumbnail(info);
     }
     //如果不是显示全部，则重新过滤显示
@@ -1676,7 +1678,7 @@ bool ThumbnailListView::isAllSelectedSupportRotate()
     }
     bool isAllSelectedSupportRotate = true;
     for (const auto &path : list) {
-        if (!UnionImage_NameSpace::isImageSupportRotate(path)) { //只要有一个不能转，就都不能转
+        if (!(UnionImage_NameSpace::isImageSupportRotate(path) && QFileInfo(path).isReadable() && QFileInfo(path).isWritable())) { //只要有一个不能转，就都不能转
             isAllSelectedSupportRotate = false;
             break;
         }
@@ -1684,6 +1686,22 @@ bool ThumbnailListView::isAllSelectedSupportRotate()
     return isAllSelectedSupportRotate;
 }
 
+bool ThumbnailListView::isSelectedCanUseFavorite()
+{
+    QStringList list = selectedPaths();
+    if (list.isEmpty()) {
+        return false;
+    }
+    bool canUseFavorite = true;
+    for (const auto &path : list) {
+        if (!QFile::exists(path)) { //当有文件不存在时，不可使用收藏
+            canUseFavorite = false;
+            break;
+        }
+    }
+    return canUseFavorite;
+}
+
 bool ThumbnailListView::isSelectedCanUseDelete()
 {
     QStringList list = selectedPaths();
@@ -1693,6 +1711,9 @@ bool ThumbnailListView::isSelectedCanUseDelete()
     bool isSelectedCanUseDelete = false;
     for (const auto &path : list) {
         QFileInfo info(path);
+        if (info.isSymLink()) {
+            info = QFileInfo(info.readLink());
+        }
         //路径无写权限
         if (!QFileInfo(info.dir(), info.dir().path()).isWritable()) {
             continue;
@@ -1712,8 +1733,10 @@ void ThumbnailListView::removeSelectToTrash(QStringList paths)
     DBImgInfo info;
     int count = 0;
     for (int i = 0; i < paths.size(); i++) {
-        QString path = paths.at(i);
-        QFileInfo infox(path);
+        QFileInfo infox(paths.at(i));
+        if (infox.isSymLink()) {
+            infox = QFileInfo(infox.readLink());
+        }
         //文件或者文件夹不可写
         if (!QFileInfo(infox.dir(), infox.dir().path()).isWritable()) {
             continue;
