@@ -171,6 +171,7 @@ void BatchOperateWidget::sltSelectAll()
     m_thumbnailListView->setFocus();
     m_chooseAll->setVisible(false);
     m_cancelChooseAll->setVisible(true);
+    emit sigCancelAll(false);
 }
 //取消全选
 void BatchOperateWidget::sltUnSelectAll()
@@ -218,9 +219,7 @@ void BatchOperateWidget::sltRightRotate(bool checked)
     Q_UNUSED(checked)
     QStringList paths =  m_thumbnailListView->selectedPaths();
     //发送给子线程旋转图片
-    for (int i = 0; i < paths.size(); i++) {
-        emit ImageEngineApi::instance()->sigRotateImageFile(90, paths.at(i));
-    }
+    emit ImageEngineApi::instance()->sigRotateImageFile(90, paths);
     m_thumbnailListView->setFocus();
 }
 //逆时针旋转
@@ -229,9 +228,7 @@ void BatchOperateWidget::sltLeftRotate(bool checked)
     Q_UNUSED(checked)
     QStringList paths =  m_thumbnailListView->selectedPaths();
     //发送给子线程旋转图片
-    for (int i = 0; i < paths.size(); i++) {
-        emit ImageEngineApi::instance()->sigRotateImageFile(-90, paths.at(i));
-    }
+    emit ImageEngineApi::instance()->sigRotateImageFile(-90, paths);
     m_thumbnailListView->setFocus();
 }
 //缩略图列表选中状态发生变化
@@ -464,7 +461,7 @@ void BatchOperateWidget::batchSelectChanged(bool isBatchSelect, bool disConnectS
             m_startBatchSelect->setVisible(false);
             m_cancelBatchSelect->setVisible(true);
             //发送给时间线，刷新悬浮控件选择按钮显隐状态
-//            emit signalBatchSelectChanged(true);
+            emit signalBatchSelectChanged(true);
         } else {
             m_trashRecoveryBtn->setVisible(false);
             m_trashDeleteBtn->setVisible(false);
@@ -522,10 +519,7 @@ void BatchOperateWidget::batchSelectChanged(bool isBatchSelect, bool disConnectS
 void BatchOperateWidget::refreshBtnEnabled(bool noSelected)
 {
     //选中项数量变化，更新按钮可用状态
-    bool selectMultiple = !m_thumbnailListView->selectedPaths().isEmpty();
-    m_collection->setEnabled(selectMultiple);
-    m_leftRotate->setEnabled(selectMultiple);
-    m_rightRotate->setEnabled(selectMultiple);
+    m_collection->setEnabled(m_thumbnailListView->isSelectedCanUseFavorite());
     m_delete->setEnabled(m_thumbnailListView->isSelectedCanUseDelete());
     //选择发生变化，刷新收藏按钮状态
     if (m_collection->isVisible()) {
