@@ -66,8 +66,11 @@ void VideoInfoDialog::setVideoInfo(const QString &path)
     m_movieInfo = MovieService::instance()->getMovieInfo(QUrl::fromLocalFile(path));
     m_maxFieldWidth = width() - m_title_maxwidth - 20 * 2 - 10 * 2;
     updateBasicInfo();
-    updateCodecInfo();
-    updateAudioInfo();
+
+    if (MovieService::instance()->ffmpegIsExist()) {
+        updateCodecInfo();
+        updateAudioInfo();
+    }
 
     m_expandGroup.clear();
 
@@ -77,21 +80,23 @@ void VideoInfoDialog::setVideoInfo(const QString &path)
         m_expandGroup.at(0)->setExpand(true);
     }
 
-    if (m_containCodecInfo) {
-        appendExpandWidget(tr("Codec info"));
-        int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
-        m_expandGroup.at(index)->setContent(m_codecInfoFrame);
-        m_expandGroup.at(index)->setExpand(true);
-        //音频编码等信息默认隐藏
-        m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
-    }
+    if (MovieService::instance()->ffmpegIsExist()) {
+        if (m_containCodecInfo) {
+            appendExpandWidget(tr("Codec info"));
+            int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
+            m_expandGroup.at(index)->setContent(m_codecInfoFrame);
+            m_expandGroup.at(index)->setExpand(true);
+            //音频编码等信息默认隐藏
+            m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
+        }
 
-    if (m_containAudioInfo) {
-        appendExpandWidget(tr("Audio info"));
-        int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
-        m_expandGroup.at(index)->setContent(m_audioInfoFrame);
-        m_expandGroup.at(index)->setExpand(true);
-        m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
+        if (m_containAudioInfo) {
+            appendExpandWidget(tr("Audio info"));
+            int index = m_expandGroup.size() > 0 ? (m_expandGroup.size() - 1) : 0;
+            m_expandGroup.at(index)->setContent(m_audioInfoFrame);
+            m_expandGroup.at(index)->setExpand(true);
+            m_expandGroup.at(index)->setExpand(false);//疑似DDrawer的BUG，直接false会显示不全
+        }
     }
 
     //剔除多余不需要的焦点
@@ -116,16 +121,16 @@ void VideoInfoDialog::updateCodecInfo()
 //    clearLayout(m_basicInfoFrameLayout);
     QMap<QString, QString> codecInfoMap;
     QList<QString> codecInfoKeys;
-    codecInfoMap[tr("Video CodecID")] = m_movieInfo.videoCodec();
+    codecInfoMap[tr("Video CodecID")] = m_movieInfo.vCodecID;
     codecInfoKeys.append(tr("Video CodecID"));
 
-    codecInfoMap[tr("Video CodeRate")] = QString::number(m_movieInfo.vCodeRate) + " kbps";
+    codecInfoMap[tr("Video CodeRate")] = m_movieInfo.vCodeRate == 0 ? "-" : QString::number(m_movieInfo.vCodeRate) + " kbps";
     codecInfoKeys.append(tr("Video CodeRate"));
 
-    codecInfoMap[tr("FPS")] = QString::number(m_movieInfo.fps) + " fps";
+    codecInfoMap[tr("FPS")] = m_movieInfo.fps == 0 ? "-" : QString::number(m_movieInfo.fps) + " fps";
     codecInfoKeys.append(tr("FPS"));
 
-    codecInfoMap[tr("Proportion")] = QString::number(static_cast<double>(m_movieInfo.proportion));
+    codecInfoMap[tr("Proportion")] = m_movieInfo.proportion <= 0 ? "-" : QString::number(m_movieInfo.proportion);
     codecInfoKeys.append(tr("Proportion"));
 
     codecInfoMap[tr("Resolution")] = m_movieInfo.resolution;
@@ -139,7 +144,7 @@ void VideoInfoDialog::updateCodecInfo()
             continue;
         }
 
-        m_containBaseInfo = true;
+        m_containCodecInfo = true;
         SimpleFormField *field = new SimpleFormField;
         field->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         DFontSizeManager::instance()->bind(field, DFontSizeManager::T8);
@@ -168,22 +173,21 @@ void VideoInfoDialog::updateAudioInfo()
 {
     QMap<QString, QString> audioInfoMap;
     QList<QString> audioInfoKeys;
-    audioInfoMap[tr("Audio CodecID")] = m_movieInfo.audioCodec();
+    audioInfoMap[tr("Audio CodecID")] = m_movieInfo.aCodeID;
     audioInfoKeys.append(tr("Audio CodecID"));
 
-    audioInfoMap[tr("Audio CodeRate")] = QString::number(m_movieInfo.aCodeRate) + " kbps";
+    audioInfoMap[tr("Audio CodeRate")] = m_movieInfo.aCodeRate == 0 ? "-" : QString::number(m_movieInfo.aCodeRate) + " kbps";
     audioInfoKeys.append(tr("Audio CodeRate"));
 
-    audioInfoMap[tr("Audio digit")] = QString::number(m_movieInfo.aDigit) + " bits";
+    audioInfoMap[tr("Audio digit")] = m_movieInfo.aDigit;
     audioInfoKeys.append(tr("Audio digit"));
 
-    audioInfoMap[tr("Channels")] = QString::number(m_movieInfo.channels) + tr("Channel");
+    audioInfoMap[tr("Channels")] = m_movieInfo.channels == 0 ? "-" : QString::number(m_movieInfo.channels) + tr("Channel");
     audioInfoKeys.append(tr("Channels"));
 
-    audioInfoMap[tr("Sampling")] = QString::number(m_movieInfo.sampling) + " hz";
+    audioInfoMap[tr("Sampling")] = m_movieInfo.sampling == 0 ? "-" : QString::number(m_movieInfo.sampling) + " hz";
     audioInfoKeys.append(tr("Sampling"));
 
-
     for (int i = 0; i < audioInfoKeys.size(); i++) {
         QString key = audioInfoKeys.at(i);
         QString value = audioInfoMap[key];
@@ -237,13 +241,13 @@ void VideoInfoDialog::updateBasicInfo()
         basicInfoMap[tr("Date modified")] = info.birthTime().toString("yyyy/MM/dd HH:mm");
         basicInfoKeys.append(tr("Date modified"));
     }
-    basicInfoMap[tr("Type")] = m_movieInfo.fileType;
+    basicInfoMap[tr("Type")] = m_movieInfo.fileType.toLower();
     basicInfoKeys.append(tr("Type"));
 
     basicInfoMap[tr("File size")] = m_movieInfo.sizeStr();
     basicInfoKeys.append(tr("File size"));
 
-    basicInfoMap[tr("Duration")] = m_movieInfo.durationStr();
+    basicInfoMap[tr("Duration")] = m_movieInfo.duration;
     basicInfoKeys.append(tr("Duration"));
 
     //trash目录不显示路径
@@ -259,7 +263,7 @@ void VideoInfoDialog::updateBasicInfo()
             continue;
         }
 
-        m_containCodecInfo = true;
+        m_containBaseInfo = true;
         SimpleFormField *field = new SimpleFormField;
         field->setAlignment(Qt::AlignLeft | Qt::AlignTop);
         DFontSizeManager::instance()->bind(field, DFontSizeManager::T8);
@@ -353,7 +357,7 @@ QString VideoInfoDialog::SpliteText(const QString &text, const QFont &font, int
                 textSplite += qstrLeftData;
             } else {
                 qstrLeftData = textTotal.left(nPos);
-                textSplite += qstrLeftData + "\n";
+                textSplite += qstrLeftData + "<br>";
             }
             textTotal = textTotal.mid(nPos);
         }
@@ -411,24 +415,27 @@ void VideoInfoDialog::initUI()
     m_basicInfoFrameLayout->setContentsMargins(10, 1, 7, 10);
     m_basicInfoFrameLayout->setLabelAlignment(Qt::AlignLeft);
     m_basicInfoFrame->setLayout(m_basicInfoFrameLayout);
-    //编码信息
-    m_codecInfoFrame = new QFrame(this);
-    m_codecInfoFrame->setFixedWidth(280);
-    m_codecInfoFrameLayout = new QFormLayout();
-    m_codecInfoFrameLayout->setVerticalSpacing(7);
-    m_codecInfoFrameLayout->setHorizontalSpacing(16);
-    m_codecInfoFrameLayout->setContentsMargins(10, 1, 7, 10);
-    m_codecInfoFrameLayout->setLabelAlignment(Qt::AlignLeft);
-    m_codecInfoFrame->setLayout(m_codecInfoFrameLayout);
-    //音频流信息
-    m_audioInfoFrame = new QFrame(this);
-    m_audioInfoFrame->setFixedWidth(280);
-    m_audioInfoFrameLayout = new QFormLayout();
-    m_audioInfoFrameLayout->setVerticalSpacing(7);
-    m_audioInfoFrameLayout->setHorizontalSpacing(16);
-    m_audioInfoFrameLayout->setContentsMargins(10, 1, 7, 10);
-    m_audioInfoFrameLayout->setLabelAlignment(Qt::AlignLeft);
-    m_audioInfoFrame->setLayout(m_audioInfoFrameLayout);
+
+    if (MovieService::instance()->ffmpegIsExist()) {
+        //编码信息
+        m_codecInfoFrame = new QFrame(this);
+        m_codecInfoFrame->setFixedWidth(280);
+        m_codecInfoFrameLayout = new QFormLayout();
+        m_codecInfoFrameLayout->setVerticalSpacing(7);
+        m_codecInfoFrameLayout->setHorizontalSpacing(16);
+        m_codecInfoFrameLayout->setContentsMargins(10, 1, 7, 10);
+        m_codecInfoFrameLayout->setLabelAlignment(Qt::AlignLeft);
+        m_codecInfoFrame->setLayout(m_codecInfoFrameLayout);
+        //音频流信息
+        m_audioInfoFrame = new QFrame(this);
+        m_audioInfoFrame->setFixedWidth(280);
+        m_audioInfoFrameLayout = new QFormLayout();
+        m_audioInfoFrameLayout->setVerticalSpacing(7);
+        m_audioInfoFrameLayout->setHorizontalSpacing(16);
+        m_audioInfoFrameLayout->setContentsMargins(10, 1, 7, 10);
+        m_audioInfoFrameLayout->setLabelAlignment(Qt::AlignLeft);
+        m_audioInfoFrame->setLayout(m_audioInfoFrameLayout);
+    }
 
     DWidget *content = new DWidget();
     addContent(content);
