@@ -1,4 +1,59 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ms" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
+<context>
+    <name/>
+    <message>
+        <source>Delete</source>
+        <translation type="vanished">Padam</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="vanished">Skrin penuh</translation>
+    </message>
+    <message>
+        <source>Slide show</source>
+        <translation type="vanished">Persembahan slaid</translation>
+    </message>
+    <message>
+        <source>Export</source>
+        <translation type="vanished">Eksport</translation>
+    </message>
+    <message>
+        <source>Copy</source>
+        <translation type="vanished">Salin</translation>
+    </message>
+    <message>
+        <source>Favorite</source>
+        <translation type="vanished">Kegemaran</translation>
+    </message>
+    <message>
+        <source>Rotate clockwise</source>
+        <translation type="vanished">Putar ikut jam</translation>
+    </message>
+    <message>
+        <source>Rotate counterclockwise</source>
+        <translation type="vanished">Putar lawan jam</translation>
+    </message>
+    <message>
+        <source>Set as wallpaper</source>
+        <translation type="vanished">Tetap sebagai kertas dinding</translation>
+    </message>
+    <message>
+        <source>Display in file manager</source>
+        <translation type="vanished">Papar dalam pengurus fail</translation>
+    </message>
+    <message>
+        <source>Photo info</source>
+        <translation type="vanished">Maklumat foto</translation>
+    </message>
+    <message>
+        <source>Video info</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Restore</source>
+        <translation type="vanished">Pulih</translation>
+    </message>
+</context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
@@ -62,10 +117,6 @@
         <source>Or drag photos here</source>
         <translation>Atau seret foto di sini</translation>
     </message>
-    <message>
-        <source>%1 photo(s)</source>
-        <translation>%1 foto</translation>
-    </message>
     <message>
         <source>Import All</source>
         <translation>Import Semua</translation>
@@ -111,7 +162,7 @@
         <translation type="unfinished"/>
     </message>
     <message>
-        <source>The files will be permanently deleted after the days shown on it</source>
+        <source>The files will be permanently deleted after the days shown on them</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -201,6 +252,25 @@
         <translation>sudah wujud. Anda mahu menggantikannya?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -235,13 +305,6 @@
         <translation>Batal</translation>
     </message>
 </context>
-<context>
-    <name>ExtensionPanel</name>
-    <message>
-        <source>Photo info</source>
-        <translation>Maklumat foto</translation>
-    </message>
-</context>
 <context>
     <name>ImageEngineApi</name>
     <message>
@@ -265,7 +328,7 @@
     </message>
     <message>
         <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>Anda pasti mahu memadam foto ini dari album?</translation>
+        <translation type="vanished">Anda pasti mahu memadam foto ini dari album?</translation>
     </message>
     <message numerus="yes">
         <source>Are you sure you want to delete %n photos from albums?</source>
@@ -283,6 +346,38 @@
         <source>Are you sure you want to delete %n items from albums?</source>
         <translation type="unfinished"><numerusform></numerusform></translation>
     </message>
+    <message>
+        <source>Are you sure you want to permanently delete this file?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>ImgInfoDialog</name>
@@ -295,8 +390,8 @@
         <translation>Perincian</translation>
     </message>
     <message>
-        <source>Photo info</source>
-        <translation>Maklumat foto</translation>
+        <source>Image info</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -340,6 +435,10 @@
         <source>All photos and videos</source>
         <translation>Semua foto dan video</translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -376,13 +475,6 @@
         <translation>Album baharu</translation>
     </message>
 </context>
-<context>
-    <name>LockWidget</name>
-    <message>
-        <source>You have no permission to view the file</source>
-        <translation type="unfinished"/>
-    </message>
-</context>
 <context>
     <name>Main</name>
     <message>
@@ -524,10 +616,6 @@
         <source>Settings</source>
         <translation>Tetapan</translation>
     </message>
-    <message>
-        <source>Import photos</source>
-        <translation>Import foto</translation>
-    </message>
     <message>
         <source>Importing...</source>
         <translation>Mengimport...</translation>
@@ -560,6 +648,30 @@
         <source>Photo/Video info</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Import photos and videos</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -644,8 +756,8 @@
         <translation>Tag</translation>
     </message>
     <message>
-        <source>Photo name</source>
-        <translation>Nama foto</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -816,29 +928,6 @@
         <translation type="unfinished"><numerusform></numerusform></translation>
     </message>
 </context>
-<context>
-    <name>SlideShowBottomBar</name>
-    <message>
-        <source>Pause</source>
-        <translation>Jeda</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation>Main</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation>Keluar</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Terdahulu</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Berikutnya</translation>
-    </message>
-</context>
 <context>
     <name>StatusBar</name>
     <message>
@@ -866,49 +955,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>TTBContent</name>
-    <message>
-        <source>Back</source>
-        <translation>Undur</translation>
-    </message>
-    <message>
-        <source>Previous</source>
-        <translation>Terdahulu</translation>
-    </message>
-    <message>
-        <source>Next</source>
-        <translation>Berikutnya</translation>
-    </message>
-    <message>
-        <source>1:1 Size</source>
-        <translation>Saiz 1:1</translation>
-    </message>
-    <message>
-        <source>Fit to window</source>
-        <translation>Suai muat tetingkap</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Putar lawan jam</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Putar ikut jam</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Padam</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Kegemaran</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Nyahgemar</translation>
-    </message>
-</context>
 <context>
     <name>ThumbnailListView</name>
     <message>
@@ -992,17 +1038,6 @@
         <translation>hari</translation>
     </message>
 </context>
-<context>
-    <name>ThumbnailWidget</name>
-    <message>
-        <source>No image files found</source>
-        <translation>Tiada fail imej ditemui</translation>
-    </message>
-    <message>
-        <source>Photo not found</source>
-        <translation>Foto tidak ditemui</translation>
-    </message>
-</context>
 <context>
     <name>TimeLineView</name>
     <message>
@@ -1084,10 +1119,6 @@
         <source>Sampling</source>
         <translation type="unfinished"/>
     </message>
-    <message>
-        <source>Video name</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Date modified</source>
         <translation>Tarikh diubah suai</translation>
@@ -1116,84 +1147,9 @@
         <source>Date captured</source>
         <translation>Tarikh ditangkap</translation>
     </message>
-</context>
-<context>
-    <name>ViewPanel</name>
     <message>
-        <source>Add to album</source>
-        <translation>Tambah kepada album</translation>
-    </message>
-    <message>
-        <source>Slide show</source>
-        <translation>Persembahan slaid</translation>
-    </message>
-    <message>
-        <source>Exit fullscreen</source>
-        <translation>Keluar dari skrin penuh</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation>Skrin penuh</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation>Salin</translation>
-    </message>
-    <message>
-        <source>Delete</source>
-        <translation>Padam</translation>
-    </message>
-    <message>
-        <source>Show navigation window</source>
-        <translation>Tunjuk tetingkap pengemudian</translation>
-    </message>
-    <message>
-        <source>Hide navigation window</source>
-        <translation>Sembunyi tetingkap pengemudian</translation>
-    </message>
-    <message>
-        <source>Rotate clockwise</source>
-        <translation>Putar ikut jam</translation>
-    </message>
-    <message>
-        <source>Rotate counterclockwise</source>
-        <translation>Putar lawan jam</translation>
-    </message>
-    <message>
-        <source>Set as wallpaper</source>
-        <translation>Tetap sebagai kertas dinding</translation>
-    </message>
-    <message>
-        <source>Display in file manager</source>
-        <translation>Papar dalam pengurus fail</translation>
-    </message>
-    <message>
-        <source>Export</source>
-        <translation>Eksport</translation>
-    </message>
-    <message>
-        <source>Unfavorite</source>
-        <translation>Nyahgemar</translation>
-    </message>
-    <message>
-        <source>Photo info</source>
-        <translation>Maklumat foto</translation>
-    </message>
-    <message>
-        <source>Remove from album</source>
-        <translation>Buang daripada album</translation>
-    </message>
-    <message>
-        <source>Favorite</source>
-        <translation>Kegemaran</translation>
-    </message>
-    <message>
-        <source>New album</source>
-        <translation>Album baharu</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation>Cetak</translation>
+        <source>Name</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 </TS>
\ No newline at end of file
